@@ -1,7 +1,6 @@
-from decorated import util
+# -*- coding: utf-8 -*-
 from decorated.function import Function, BoundedFunction, PartialFunction
 
 Function = Function
 PartialFunction = PartialFunction
 BoundedFunction = BoundedFunction
-retries = util.retries
